.. SPDX-FileCopyrightText: Copyright © 2024 Idiap Research Institute <contact@idiap.ch>
..
.. SPDX-License-Identifier: GPL-3.0-or-later

.. _mednet.databases.classify.indian:

==============================
 Indian (Dataset A/Dataset B)
==============================

* DataModule and support code: :py:mod:`.data.classify.indian`
* Splits:

  .. list-table::
     :align: left

     * - Config. key
       - Module
     * - ``indian``
       - :py:mod:`.config.classify.data.indian.default`
     * - ``indian-f0``
       - :py:mod:`.config.classify.data.indian.fold_0`
     * - ``indian-f1``
       - :py:mod:`.config.classify.data.indian.fold_1`
     * - ``indian-f2``
       - :py:mod:`.config.classify.data.indian.fold_2`
     * - ``indian-f3``
       - :py:mod:`.config.classify.data.indian.fold_3`
     * - ``indian-f4``
       - :py:mod:`.config.classify.data.indian.fold_4`
     * - ``indian-f5``
       - :py:mod:`.config.classify.data.indian.fold_5`
     * - ``indian-f6``
       - :py:mod:`.config.classify.data.indian.fold_6`
     * - ``indian-f7``
       - :py:mod:`.config.classify.data.indian.fold_7`
     * - ``indian-f8``
       - :py:mod:`.config.classify.data.indian.fold_8`
     * - ``indian-f9``
       - :py:mod:`.config.classify.data.indian.fold_9`
